Matching Strategies - durian.match.strategy — durian v0.0.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.2 documentation »
- Module API Reference »

# Matching Strategies - durian.match.strategy

`durian.match.strategy.` `deepmatch`(needle, haystack)
  With a needle dictionary, recursively match all its keys to the haystack dictionary.

### Navigation

- index
- modules |
- next |
- previous |
- durian v0.0.2 documentation »
- Module API Reference »